@@ -15,7 +15,8 @@
 #include "ssmping.h"
 
 #ifdef WIN32
-#include "mswsock.h"
+#include <mswsock.h>
+#include <windns.h>
 
 /* further definitions missing from my mswsock.h */
 #ifndef WSAID_WSARECVMSG
@@ -462,6 +463,37 @@ int ismc(struct sockaddr *sa) {
     return 0;
 }
 
+#ifdef WIN32
+#ifndef DNS_TYPE_SRV
+#define DNS_TYPE_SRV 33
+#endif
+
+char *getsrv(const char *name) {
+    DNS_RECORD *dnsrecords, *dnsrecord;
+    void *dnsrsv;
+    char *srvname;
+    
+    srvname = malloc(strlen(name) + strlen("_ldap._tcp.") + 1);
+    sprintf(srvname, "_ldap._tcp.%s", name);
+    
+    if (DnsQuery_A(srvname, DNS_TYPE_SRV, DNS_QUERY_STANDARD, NULL, &dnsrecords, &dnsrsv))
+	return NULL;
+    for (dnsrecord = dnsrecords; dnsrecord; dnsrecord = dnsrecord->pNext) {
+#if 0	
+	printf("dnsname = %s\n", dnsrecord->pName);
+	printf("dnstype = %d\n", dnsrecord->wType);
+#endif	
+	if (dnsrecord->wType == DNS_TYPE_SRV) {
+	    free(srvname);
+	    return dnsrecord->Data.Srv.pNameTarget;
+	}
+    }
+    free(srvname);
+    DnsRecordListFree(dnsrecords, DnsFreeRecordList);
+    return NULL;
+}
+#endif    
+
 /* return 0 if ok, -1 on error. creates sockets s1, s2 if not NULL
  * mcaddr must be mc and ucaddr uc, unless both specified, in which
  * case one must be uc and the other mc
@@ -471,7 +503,7 @@ int names2addrsocks(int *s1, int *s2, const char *ucaddr, const char *mcaddr, co
     struct addrinfo hints, *res1, *res2;
     const char *addr;
     int e;
-
+    
     addr = mcaddr ? mcaddr : ucaddr;
     if (!addr)
 	return -1;
@@ -485,6 +517,10 @@ int names2addrsocks(int *s1, int *s2, const char *ucaddr, const char *mcaddr, co
     hints.ai_family = *family;
     hints.ai_socktype = SOCK_DGRAM;
 
+#ifdef WIN32
+    printf("SRV target %s\n", getsrv(addr));
+#endif
+    
     if ((e = getaddrinfo(addr, srv, &hints, &res1))) {
 #ifdef WIN32
 	err("getaddrinfo failed with error code %d", e);
@@ -816,8 +852,12 @@ int doit(int ver, int size, int count, int us, int ms, struct sockaddr_storage *
 	
 	parsepacket(recvbuf + 1, cnt - 1, &verstring, &recvdata);
 	
+#ifndef WIN32
+	mc = s == ms;
+#endif
+	
 	if (recvdata.pid != pid) {
-	    printf("received someone else's reply\n");
+	    printf("received someone else's %sicast reply\n", mc ? "mult" : "un");
 	    continue;
 	}
 
@@ -837,12 +877,9 @@ int doit(int ver, int size, int count, int us, int ms, struct sockaddr_storage *
 	    dist = 128 - hops;
 	else
 	    dist = 64 - hops;
-#ifndef WIN32
-	mc = s == ms;
-#endif
 	
-	printf("%s from %s, seq=%d dist=%d time=%ld.%03ld ms",
-	       mc ? "multicast" : "  unicast",
+	printf("%sicast from %s, seq=%d dist=%d time=%ld.%03ld ms",
+	       mc ? "mult" : "  un",
 	       addr2string((struct sockaddr *) &from, fromlen),
 	       recvdata.seq, dist,
 	       diff.tv_sec * 1000 + diff.tv_usec / 1000, diff.tv_usec % 1000);
